summaryrefslogtreecommitdiffstats
path: root/src/H5P.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5P.c')
-rw-r--r--src/H5P.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/H5P.c b/src/H5P.c
index 6969097..d2d95c3 100644
--- a/src/H5P.c
+++ b/src/H5P.c
@@ -664,7 +664,7 @@ H5Pset(hid_t plist_id, const char *name, const void *value)
if (!name || !*name)
HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid property name");
if (value == NULL)
- HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalied property value");
+ HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid property value");
/* Go set the value */
if (H5P_set(plist, name, value) < 0)
@@ -678,7 +678,7 @@ done:
NAME
H5Pexist
PURPOSE
- Routine to query the existance of a property in a property object.
+ Routine to query the existence of a property in a property object.
USAGE
htri_t H5P_exist(id, name)
hid_t id; IN: Property object ID to check
@@ -712,7 +712,7 @@ H5Pexist(hid_t id, const char *name)
if (!name || !*name)
HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid property name");
/* Check for the existance of the property in the list or class */
if (H5I_GENPROP_LST == H5I_get_type(id)) {
if (NULL == (plist = (H5P_genplist_t *)H5I_object(id)))
HGOTO_ERROR(H5E_ARGS, H5E_BADTYPE, FAIL, "not a property list");
@@ -856,7 +856,7 @@ done:
Failure: H5I_INVALID_HID (negative)
DESCRIPTION
Decodes a property list from a binary buffer. The contents of the buffer
- contain the values for the correponding properties of the plist. The decode
+ contain the values for the corresponding properties of the plist. The decode
callback of a certain property decodes its value from the buffer and sets it
in the property list.
GLOBAL VARIABLES
@@ -1274,7 +1274,7 @@ H5Pget(hid_t plist_id, const char *name, void *value)
if (!name || !*name)
HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid property name");
if (value == NULL)
- HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalied property value");
+ HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid property value");
/* Go get the value */
if (H5P_get(plist, name, value) < 0)
@@ -1297,7 +1297,7 @@ done:
Returns non-negative on success, negative on failure.
DESCRIPTION
Removes a property from a property list. Both properties which were
- in existance when the property list was created (i.e. properties registered
+ in existence when the property list was created (i.e. properties registered
with H5Pregister2) and properties added to the list after it was created
(i.e. added with H5Pinsert2) may be removed from a property list.
Properties do not need to be removed a property list before the list itself
@@ -712,7 +712,7 @@ H5Pexist(hid_t id, const char *name)
if (!name || !*name)
HGOTO_ERROR(H5E_ARGS, H5E_BADVALUE, FAIL, "invalid property name");
- /* Check for the existance of the property in the list or class */
+ /* Check for the existence of the property in the list or class */
if (H5I_GENPROP_LST == H5I_get_type(id)) {
if (NULL == (plist = (H5P_genplist_t *)H5I_object(id)))